@@ -1,7 +1,7 @@
 #!/bin/sh
 #   sge
 #$ -S /bin/sh 
-COSMOSTOP=~/Cosmos7.50T
+COSMOSTOP=~/Cosmos7.51
 export COSMOSTOP
 cd $COSMOSTOP/UserHook/mkLDD
 source  /home/Users/sgeadmin/SGE/default/common/settings.sh 
